@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use feature qw/state/;
 
-our $VERSION = '0.000013';
+our $VERSION = '0.000014';
 
 use Carp qw/confess croak cluck/;
 use Scalar::Util qw/blessed weaken/;
@@ -969,4 +969,34 @@ These are shortcuts for:
 
 =back
 
+=head1 SOURCE
+
+The source code repository for DBIx-QuickORM can be found at
+L<http://github.com/exodist/DBIx-QuickORM/>.
+
+=head1 MAINTAINERS
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 AUTHORS
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 COPYRIGHT
+
+Copyright Chad Granum E<lt>exodist7@gmail.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See L<http://dev.perl.org/licenses/>
+
 =cut
