@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use feature qw/state/;
 
-our $VERSION = '0.000013';
+our $VERSION = '0.000014';
 
 use Carp qw/confess croak carp/;
 use Sub::Util qw/set_subname/;
@@ -2074,3 +2074,35 @@ Run the callback for each row found.
 In data_only mode this will provide hashrefs instead of blessed row objects.
 
 =back
+
+=head1 SOURCE
+
+The source code repository for DBIx-QuickORM can be found at
+L<http://github.com/exodist/DBIx-QuickORM/>.
+
+=head1 MAINTAINERS
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 AUTHORS
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 COPYRIGHT
+
+Copyright Chad Granum E<lt>exodist7@gmail.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See L<http://dev.perl.org/licenses/>
+
+=cut
